bayespy.inference.vmp.nodes.gaussian.GaussianGammaDistribution.compute_moments_and_cgf
======================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaDistribution.compute_moments_and_cgf